import { p as parser } from './liquidsoap-a9bd57d1.js';
import { LRLanguage, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@lezer/highlight';
import '@lezer/lr';

const LiquidsoapLanguage = LRLanguage.define({
    parser: parser.configure({
        props: [
            styleTags({
                Var: tags.variableName,
                "Type/...": tags.typeName,
                Bool: tags.bool,
                String: tags.string,
                "Method/...": tags.propertyName,
                "LabeledArgument/...": tags.labelName,
                Integer: tags.integer,
                Float: tags.float,
                Regexp: tags.regexp,
                EscapedChar: tags.escape,
                Op: tags.operatorKeyword,
                "LetDecoration/...": tags.modifier,
                "Defined/Var": tags.definition(tags.variableName),
                "Defined/Varlpar": tags.definition(tags.function(tags.variableName)),
                "Defined/Subfield/*/Var": tags.definition(tags.propertyName),
                "Defined/SubfieldLpar/*/Varlpar": tags.definition(tags.function(tags.propertyName)),
                "SubfieldLpar/*/Varlpar": tags.function(tags.propertyName),
                Varlpar: tags.function(tags.variableName),
                LineComment: tags.lineComment,
                BlockComment: tags.blockComment,
                DocComment: tags.docComment,
                "ControlKeyword/...": tags.controlKeyword,
                "Keyword/...": tags.keyword,
                "DefinitionKeyword/...": tags.definitionKeyword,
                "LogicOperator/...": tags.logicOperator,
                "CompareOperator/...": tags.compareOperator,
                "ArithmeticOperator/...": tags.arithmeticOperator,
                DerefOp: tags.derefOperator,
                UpdateOp: tags.updateOperator,
                "( )": tags.paren,
                "{ }": tags.brace,
                "[ ]": tags.squareBracket,
            }),
        ],
    }),
    languageData: {
        commentTokens: { line: ";" },
    },
});
function liquidsoap() {
    return new LanguageSupport(LiquidsoapLanguage);
}

export { LiquidsoapLanguage, liquidsoap };
